nltk.translate package
======================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.translate.api
   nltk.translate.bleu_score
   nltk.translate.chrf_score
   nltk.translate.gale_church
   nltk.translate.gdfa
   nltk.translate.gleu_score
   nltk.translate.ibm1
   nltk.translate.ibm2
   nltk.translate.ibm3
   nltk.translate.ibm4
   nltk.translate.ibm5
   nltk.translate.ibm_model
   nltk.translate.meteor_score
   nltk.translate.metrics
   nltk.translate.nist_score
   nltk.translate.phrase_based
   nltk.translate.ribes_score
   nltk.translate.stack_decoder

Module contents
---------------

.. automodule:: nltk.translate
   :members:
   :undoc-members:
   :show-inheritance:
